@@ -53,16 +53,14 @@ has_element 'msg' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::msgType",
 	coerce => 1,
+	required => 1,
+	lazy => 1,
+	default => sub {
+		my $self = shift;
+		$result_codes{$self->code};
+	},
 	;
 
-sub BUILD {
-	my $self = shift;
-	my $msg = $self->msg;
-	if ( !$msg and ($msg = $result_codes{$self->code}) ) {
-		$self->msg($msg);
-	}
-}
-
 subtype "${PKG}::choice0"
 	=> as join("|", map { "${SCHEMA_PKG}::$_" }
 			   qw(errValueType extErrValueType)),
@@ -81,6 +79,7 @@ has_element 'errors' =>
 	handles => {
 		add_error => 'push',
 	},
+	default => sub { [] },
 	xml_min => 0,
 	;
 
